@@ -8,7 +8,7 @@ use CAD::OpenSCAD::Math;
 
 our $Math=new CAD::OpenSCAD::Math;
 
-our $VERSION='0.12.1';
+our $VERSION='0.12.2';
 
 =head1 NAME
 
@@ -50,7 +50,7 @@ for subsequent transformations
 =cut
 
 
-class CAD::OpenSCAD{
+class OpenSCAD{
    field $script :reader :param  //="";
    field $items  :reader :writer //={};
    field $fa     :writer :reader :param //=1;
